[Pkg-owncloud-commits] [owncloud-client] 424/484: NautilusPlugin: Fix behaviour with files with a colon in the name.

Sandro Knauß hefee-guest at moszumanska.debian.org
Wed Dec 16 00:38:16 UTC 2015


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit 29e2877d35630d9b660660305557076013c05193
Author: Klaas Freitag <freitag at owncloud.com>
Date:   Wed Nov 25 15:09:56 2015 +0100

    NautilusPlugin: Fix behaviour with files with a colon in the name.
---
 shell_integration/nautilus/syncstate.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/shell_integration/nautilus/syncstate.py b/shell_integration/nautilus/syncstate.py
index d1d4214..3223362 100755
--- a/shell_integration/nautilus/syncstate.py
+++ b/shell_integration/nautilus/syncstate.py
@@ -259,8 +259,8 @@ class SyncStateExtension(GObject.GObject, Nautilus.ColumnProvider, Nautilus.Info
                     if( not itemStore['state'] or newState != itemStore['state'] ):
                         item = itemStore['item']
                         item.add_emblem(emblem)
-                        # print("Setting emblem on " + args[1] + "<>" + emblem + "<>")  # For debug only
-                        socketConnect.nautilusVFSFile_table[args[1]] = {'item': item, 'state':newState}
+                        # print("Setting emblem on " + filename + "<>" + emblem + "<>")  # For debug only
+                        socketConnect.nautilusVFSFile_table[filename] = {'item': item, 'state':newState}
 
         elif action == 'UPDATE_VIEW':
             # Search all items underneath this path and invalidate them

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list